# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.1.9

No merged PRs

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.1.8

No merged PRs

## 0.1.7

No merged PRs

## 0.1.6

([Full Changelog](https://github.com/c3di/vp4jl/compare/v0.1.4...d9e6953fbccab93a98224798f5b359363e705969))

### Enhancements made

- Add display intermediate image [#124](https://github.com/c3di/vp4jl/pull/124) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Feat/update readme [#122](https://github.com/c3di/vp4jl/pull/122) ([@Max-ChenFei](https://github.com/Max-ChenFei))

### Other merged PRs

- Feat/intermediate image vis [#125](https://github.com/c3di/vp4jl/pull/125) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Feat/update readme [#123](https://github.com/c3di/vp4jl/pull/123) ([@Max-ChenFei](https://github.com/Max-ChenFei))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/c3di/vp4jl/graphs/contributors?from=2023-09-13&to=2024-07-18&type=c))

[@Max-ChenFei](https://github.com/search?q=repo%3Ac3di%2Fvp4jl+involves%3AMax-ChenFei+updated%3A2023-09-13..2024-07-18&type=Issues)

## 0.1.4

([Full Changelog](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/compare/v0.1.3...52982f6f06b748b0a999052cee95b7d9c8510608))

### Enhancements made

- add more nodes [#120](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/120) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Update readme and extensions [#117](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/117) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Fix/save output to disk [#113](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/113) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Feat/vp cell [#110](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/110) ([@Max-ChenFei](https://github.com/Max-ChenFei))

### Bugs fixed

- Remove unnecessary update for vp cell widget [#118](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/118) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Unititled-document [#114](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/114) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Set isUntitled true for vp widget  [#111](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/111) ([@Max-ChenFei](https://github.com/Max-ChenFei))

### Documentation improvements

- Feat/update readme [#119](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/119) ([@Max-ChenFei](https://github.com/Max-ChenFei))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/graphs/contributors?from=2023-08-05&to=2023-09-13&type=c))

[@Max-ChenFei](https://github.com/search?q=repo%3AMax-ChenFei%2FVisualProgramming4JupyterLab+involves%3AMax-ChenFei+updated%3A2023-08-05..2023-09-13&type=Issues)

## 0.1.3

([Full Changelog](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/compare/v0.1.2...1a66fb4a0938eb1e0d4b8d986595f698db398dda))

### Bugs fixed

- Fix/kernel selection when reboot [#108](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/108) ([@Max-ChenFei](https://github.com/Max-ChenFei))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/graphs/contributors?from=2023-08-04&to=2023-08-05&type=c))

[@Max-ChenFei](https://github.com/search?q=repo%3AMax-ChenFei%2FVisualProgramming4JupyterLab+involves%3AMax-ChenFei+updated%3A2023-08-04..2023-08-05&type=Issues)

## 0.1.2

([Full Changelog](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/compare/v0.1.1...0b58e4bc4ad0b53bd2a65b84f1a1f7edc38266d3))

### Enhancements made

- Cleanup [#105](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/105) ([@Max-ChenFei](https://github.com/Max-ChenFei))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/graphs/contributors?from=2023-08-04&to=2023-08-04&type=c))

[@Max-ChenFei](https://github.com/search?q=repo%3AMax-ChenFei%2FVisualProgramming4JupyterLab+involves%3AMax-ChenFei+updated%3A2023-08-04..2023-08-04&type=Issues)

## 0.1.1

([Full Changelog](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/compare/308159c55b7a3512b4286d71f3acf96b87c20435...4151f7b1b7427d82dca5f0673b0f762d3ca2150e))

### Enhancements made

- Fix/node library management [#89](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/89) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Paste or duplicate the nodes near the old node using the command directly, not mouse pos, [#84](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/84) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Feat/output area [#82](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/82) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Add toggle node extension panel command and add to menu [#80](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/80) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Fix/run and kernel menu [#79](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/79) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Feat/tool bar [#78](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/78) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Refactoring/vp model [#70](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/70) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Refactoring/model context widget [#69](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/69) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Add kernel status [#68](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/68) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Feat/kernel status management [#66](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/66) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Feat/kernel switch [#64](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/64) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Refractory [#62](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/62) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- add new vp file to the context menu [#61](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/61) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Feat/bump jupyerlab [#60](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/60) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Feat/kernel selection [#53](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/53) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Feat/node library management [#47](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/47) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Add unique id to the widget [#40](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/40) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Feat/center content after open [#39](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/39) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Fix reload from the disk bug [#38](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/38) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Close the default context menu when clicking the side bar and switch tab [#37](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/37) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Feat/new file command [#36](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/36) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Restore the widget after refresh window [#33](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/33) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Feat/close menu when click other area [#32](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/32) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Upgrade the dependency [#27](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/27) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Feat/save file [#26](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/26) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Feat/vp editor show content [#20](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/20) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Feat/vp widget&factory [#18](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/18) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Add model and model factory [#13](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/13) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Feat/document file type [#6](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/6) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Feat/Setup [#2](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/2) ([@Max-ChenFei](https://github.com/Max-ChenFei))

### Bugs fixed

- Remove unnecessary update [#97](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/97) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Node-library-management [#92](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/92) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Fix/node library management [#89](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/89) ([@Max-ChenFei](https://github.com/Max-ChenFei))
- Fix/close menu on switch tab [#30](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/30) ([@Max-ChenFei](https://github.com/Max-ChenFei))

### Other merged PRs

- Feat/css coherence with jp [#98](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/pull/98) ([@xp1632](https://github.com/xp1632))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/Max-ChenFei/VisualProgramming4JupyterLab/graphs/contributors?from=2023-04-17&to=2023-08-04&type=c))

[@Max-ChenFei](https://github.com/search?q=repo%3AMax-ChenFei%2FVisualProgramming4JupyterLab+involves%3AMax-ChenFei+updated%3A2023-04-17..2023-08-04&type=Issues) | [@xp1632](https://github.com/search?q=repo%3AMax-ChenFei%2FVisualProgramming4JupyterLab+involves%3Axp1632+updated%3A2023-04-17..2023-08-04&type=Issues)
